@@ -25,8 +25,9 @@
 
 `minimize` <-
 function(input, include = "", dir.exp = NULL, details = FALSE, all.sol = FALSE,
-        row.dom = FALSE, min.pin = FALSE, pi.cons = 0, pi.depth = 0, sol.cons = 0,
-        sol.cov = 1, sol.depth = 0, method = "CCubes", ...) {
+        pi.cons = 0, pi.depth = 0, sol.cons = 0, sol.cov = 1, sol.depth = 0,
+        row.dom = FALSE, min.pin = FALSE, max.comb = 0, first.min = FALSE,
+        method = "CCubes", ...) {
     metacall <- match.call()
     dots <- substitute(list(...))
     if (is.element("data", names(dots))) {
@@ -90,8 +91,8 @@ function(input, include = "", dir.exp = NULL, details = FALSE, all.sol = FALSE,
     inf.test    <- if (is.element("inf.test",    names(dots))) dots$inf.test     else ""
     relation    <- if (is.element("relation",    names(dots))) dots$relation     else "sufficiency"
     neg.out     <- if (is.element("neg.out",     names(dots))) dots$neg.out      else FALSE
-    procedure   <- if (is.element("procedure",   names(dots))) dots$procedure    else 0 
-    exclude     <- if (is.element("exclude",     names(dots))) dots$exclude      else NULL 
+    procedure   <- if (is.element("procedure",   names(dots))) dots$procedure    else 0
+    exclude     <- if (is.element("exclude",     names(dots))) dots$exclude      else NULL
     if (is.null(exclude)) {
         if (is.element("omit", names(dots))) {
             exclude <- dots$omit
@@ -317,9 +318,17 @@ function(input, include = "", dir.exp = NULL, details = FALSE, all.sol = FALSE,
             }
             expressions <- .Call("C_Cubes", list(
                             tt = cbind(rbind(pos.matrix, neg.matrix) - 1, rep(c(1, 0), c(nrow(pos.matrix), nrow(neg.matrix)))),
-                            pi.cons = pi.cons, depth = as.integer(c(pi.depth, sol.depth)),
-                            min.pin = min.pin, row.dom = row.dom, all.sol = all.sol, sol.cons = sol.cons,
-                            sol.cov = sol.cov, data = extended.data, fs = tt$fs),
+                            data = extended.data,
+                            all.sol = all.sol,
+                            row.dom = row.dom,
+                            min.pin = min.pin,
+                            pi.cons = pi.cons,
+                            depth = as.integer(c(pi.depth, sol.depth)),
+                            sol.cons = sol.cons,
+                            sol.cov = sol.cov,
+                            fs = tt$fs,
+                            max.comb = max.comb,
+                            first.min = first.min),
                             PACKAGE = "QCA")
         }
         callist$expressions <- expressions
@@ -520,6 +529,7 @@ function(input, include = "", dir.exp = NULL, details = FALSE, all.sol = FALSE,
     if (!methods::is(input, "QCA_tt")) {
         output$tt$options$outcome <- outcome.copy
     }
+    output$complex <- p.sol$complex
     output$call <- metacall
     if (is.element("via.web", names(dots))) {
         output$via.web <- TRUE
