@@ -27,10 +27,5 @@
     msg <- paste("  Dusa, Adrian (2019) QCA with R. A Comprehensive Resource.",
                  "  Springer International Publishing.", sep="\n")
     msg <- paste(msg, "\n\nTo run the graphical user interface, use: runGUI()\n", sep="")
-    if (!grepl("there is no package called", tryCatch(find.package("QCApro"), error = function(e) e))) {
-        msg <- paste(msg, "\nNOTE: Found multiple function name conflicts with the fork package QCApro.",
-                          "\n      To avoid confusion, it should be unloaded before using this software, with:", 
-                          "\n      unload(QCApro)", sep = "")
-    }
     packageStartupMessage("\nTo cite package QCA in publications, please use:\n", msg, "\n")
 }
